@@ -6,7 +6,9 @@ from fabric.decorators import task
 from fabric.utils import puts
 
 
-def upload_file(bucket, key_name, file_path, policy='public-read'):
+def upload_file(bucket, key_name, file_path, remote_prefix=None, policy='public-read'):
+    if remote_prefix:
+        key_name = '{0}/{1}'.format(remote_prefix, key_name)
     key = bucket.new_key(key_name)
     fd = open(file_path)
     md5 = compute_md5(fd)
@@ -24,7 +26,7 @@ def get_key_name(local_path, fullpath):
 
 
 @task
-def sync_dir_up(bucket_name, local_path):
+def sync_dir_up(bucket_name, local_path, remote_prefix=None):
     puts("Sync directory {0} with bucket {1}".format(bucket_name, local_path))
     conn = boto.connect_s3()
     bucket = conn.get_bucket(bucket_name)
@@ -45,4 +47,4 @@ def sync_dir_up(bucket_name, local_path):
                     continue
 
             puts("Upload file {0}".format(file_path))
-            upload_file(bucket, key_name, file_path)
+            upload_file(bucket, key_name, file_path, remote_prefix=remote_prefix)
